# The `manipulation` python package

This package contains code to support the [Robotic Manipulation](http://manipulation.mit.edu) course notes.

```{eval-rst}
.. toctree::
   :maxdepth: 2

   station
   systems
   meshcat_utils
   utils
   create_sdf_from_mesh
   make_drake_compatible_model
```

